#include "tableview.h"

tableView::tableView(QWidget *parent)
    : QWidget(parent)
{
    //create layout
    QVBoxLayout *mainLayout = new QVBoxLayout();
    QHBoxLayout *horLayout1 = new QHBoxLayout;
    QHBoxLayout *horLayout2 = new QHBoxLayout;

    //create input number of row
    label1 = new QLabel(tr("row : "));
    lineeRow = new QLineEdit();
    horLayout1->addWidget(label1);
    horLayout1->addWidget(lineeRow);

    //create input number of column
    label2 = new QLabel(tr("Column : "));
    lineeCol = new QLineEdit();
    horLayout2->addWidget(label2);
    horLayout2->addWidget(lineeCol);

    lineeRow->setText("4");
    lineeCol->setText("2");
    btnApply = new QPushButton(tr("Apply"));
    connect(btnApply, SIGNAL(clicked()), this, SLOT(btnApply_clicked()));

    //create QTableView
    tblv = new QTableView();
    tblv->setSelectionBehavior(QAbstractItemView::SelectItems );
    tblv->setSelectionMode( QAbstractItemView::ExtendedSelection );

    //create contextmenu
    copyAction = new QAction(tr("&Copy"), this);
    copyAction->setStatusTip(tr("Copy Table Location"));
    copyAction->setShortcut(tr("Ctrl+C"));
    connect(copyAction, SIGNAL(triggered()), this, SLOT(aCopy()));

    pasteAction = new QAction(tr("&Paste"), this);
    pasteAction->setStatusTip(tr("Paste"));
    pasteAction->setShortcut(tr("Ctrl+V"));
    connect(pasteAction, SIGNAL(triggered()), this, SLOT(aPaste()));

    tblv->setContextMenuPolicy(Qt::CustomContextMenu);
    connect(tblv, SIGNAL(customContextMenuRequested( const QPoint& )),
            this, SLOT(tablev_customContextMenu( const QPoint& )));

    //connect horizontal header QTableView with contextmenu
    horizontalHeader = tblv->horizontalHeader();
    horizontalHeader->setContextMenuPolicy(Qt::CustomContextMenu);     //set contextmenu
    connect(horizontalHeader, SIGNAL(customContextMenuRequested( const QPoint& )),
            this, SLOT(tablev_customContextMenu( const QPoint& )));

    //connect vertical header QTableView with contextmenu
    verticalHeader = tblv->verticalHeader();
    verticalHeader->setContextMenuPolicy(Qt::CustomContextMenu);     //set contextmenu
    connect(verticalHeader, SIGNAL(customContextMenuRequested( const QPoint& )),
            this, SLOT(tablev_customContextMenu( const QPoint& )));

    //setting layout
    mainLayout->addLayout(horLayout1);
    mainLayout->addLayout(horLayout2);
    mainLayout->addWidget(btnApply);
    mainLayout->addWidget(tblv);
    setLayout(mainLayout);
}

//create table input context menu
void tableView::tablev_customContextMenu( const QPoint& )
{
    // check is item in QTableView exist or not
    if(boolGetItemTableView(tblv))
    {
        QMenu menu(this);
        menu.addAction(copyAction);
        menu.addAction(pasteAction);
        menu.exec(QCursor::pos());
    }
}

//get QTableView selected item
bool tableView::boolGetItemTableView(QTableView *table)
{
    // get model from tableview
    QItemSelectionModel * model = table->selectionModel();

    if(model)
        return (true);
    else                //QTableView dont have selected data
        return (false);

}


void tableView::aCopy()
{

}

void tableView::aPaste()
{

}

void tableView::btnApply_clicked()
{
    //get number of input row and column
    nrow = lineeRow->text().toInt();
    ncol = lineeCol->text().toInt();

    //create model
    QStandardItemModel *model = new QStandardItemModel( nrow, ncol, this );

    //create QTableview Horizontal Header
    for (int r=0; r<ncol; r++)
        model->setHorizontalHeaderItem( r, new QStandardItem( QString("Column_ %0" ).arg(r)) );

    //fill model value
    for( int r=0; r<nrow; r++ )
    {
        for( int c=0; c<ncol; c++)
        {
            QString sstr = "[ " + QString::number(r) + " , " + QString::number(c) + " ]";
            QStandardItem *item = new QStandardItem(QString("Idx ") + sstr);
            model->setItem(r, c, item);
        }
    }

    //set model
    tblv->setModel(model);
}
